from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_country_or_region_code_type_0_item import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemCountryOrRegionCodeType0Item
from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_employment_type_type_0_item import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemEmploymentTypeType0Item
from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_industry_type_0_item import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemIndustryType0Item
from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_job_function_type_0_item import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobFunctionType0Item
from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_job_location_type_type_0_item import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobLocationTypeType0Item
from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_job_posting_status_type_1 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType1
from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_job_posting_status_type_2_type_1 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType2Type1
from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_job_posting_status_type_3_type_1 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType3Type1
from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_seniority_type_0_item import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemSeniorityType0Item
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_annual_pay_usd_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemAnnualPayUSDType0
  from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_num_applicants_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemNumApplicantsType0
  from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_geo_location_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0
  from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1
  from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType0
  from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_years_of_experience_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemYearsOfExperienceType0





T = TypeVar("T", bound="CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0Item")



@_attrs_define
class CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0Item:
    """ 
        Attributes:
            job_posting_status (Union[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType1,
                CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType2Type1,
                CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType3Type1, None, Unset]):
            job_title (Union[None, Unset, list[str]]):
            keywords (Union[None, Unset, list[str]]):
            posted_at (Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType0',
                'CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1', None, Unset]):
            num_applicants (Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemNumApplicantsType0', None,
                Unset]):
            annual_pay_usd (Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemAnnualPayUSDType0', None,
                Unset]):
            years_of_experience (Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemYearsOfExperienceType0',
                None, Unset]):
            geo_location (Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0', None,
                Unset]):
            country_or_region_code (Union[None, Unset,
                list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemCountryOrRegionCodeType0Item]]):
            seniority (Union[None, Unset,
                list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemSeniorityType0Item]]):
            employment_type (Union[None, Unset,
                list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemEmploymentTypeType0Item]]):
            job_function (Union[None, Unset,
                list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobFunctionType0Item]]):
            industry (Union[None, Unset,
                list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemIndustryType0Item]]):
            job_location_type (Union[None, Unset,
                list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobLocationTypeType0Item]]):
     """

    job_posting_status: Union[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType1, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType2Type1, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType3Type1, None, Unset] = UNSET
    job_title: Union[None, Unset, list[str]] = UNSET
    keywords: Union[None, Unset, list[str]] = UNSET
    posted_at: Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType0', 'CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1', None, Unset] = UNSET
    num_applicants: Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemNumApplicantsType0', None, Unset] = UNSET
    annual_pay_usd: Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemAnnualPayUSDType0', None, Unset] = UNSET
    years_of_experience: Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemYearsOfExperienceType0', None, Unset] = UNSET
    geo_location: Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0', None, Unset] = UNSET
    country_or_region_code: Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemCountryOrRegionCodeType0Item]] = UNSET
    seniority: Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemSeniorityType0Item]] = UNSET
    employment_type: Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemEmploymentTypeType0Item]] = UNSET
    job_function: Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobFunctionType0Item]] = UNSET
    industry: Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemIndustryType0Item]] = UNSET
    job_location_type: Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobLocationTypeType0Item]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_annual_pay_usd_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemAnnualPayUSDType0
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_num_applicants_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemNumApplicantsType0
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_geo_location_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType0
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_years_of_experience_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemYearsOfExperienceType0
        job_posting_status: Union[None, Unset, str]
        if isinstance(self.job_posting_status, Unset):
            job_posting_status = UNSET
        elif isinstance(self.job_posting_status, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType1):
            job_posting_status = self.job_posting_status.value
        elif isinstance(self.job_posting_status, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType2Type1):
            job_posting_status = self.job_posting_status.value
        elif isinstance(self.job_posting_status, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType3Type1):
            job_posting_status = self.job_posting_status.value
        else:
            job_posting_status = self.job_posting_status

        job_title: Union[None, Unset, list[str]]
        if isinstance(self.job_title, Unset):
            job_title = UNSET
        elif isinstance(self.job_title, list):
            job_title = self.job_title


        else:
            job_title = self.job_title

        keywords: Union[None, Unset, list[str]]
        if isinstance(self.keywords, Unset):
            keywords = UNSET
        elif isinstance(self.keywords, list):
            keywords = self.keywords


        else:
            keywords = self.keywords

        posted_at: Union[None, Unset, dict[str, Any]]
        if isinstance(self.posted_at, Unset):
            posted_at = UNSET
        elif isinstance(self.posted_at, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType0):
            posted_at = self.posted_at.to_dict()
        elif isinstance(self.posted_at, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1):
            posted_at = self.posted_at.to_dict()
        else:
            posted_at = self.posted_at

        num_applicants: Union[None, Unset, dict[str, Any]]
        if isinstance(self.num_applicants, Unset):
            num_applicants = UNSET
        elif isinstance(self.num_applicants, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemNumApplicantsType0):
            num_applicants = self.num_applicants.to_dict()
        else:
            num_applicants = self.num_applicants

        annual_pay_usd: Union[None, Unset, dict[str, Any]]
        if isinstance(self.annual_pay_usd, Unset):
            annual_pay_usd = UNSET
        elif isinstance(self.annual_pay_usd, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemAnnualPayUSDType0):
            annual_pay_usd = self.annual_pay_usd.to_dict()
        else:
            annual_pay_usd = self.annual_pay_usd

        years_of_experience: Union[None, Unset, dict[str, Any]]
        if isinstance(self.years_of_experience, Unset):
            years_of_experience = UNSET
        elif isinstance(self.years_of_experience, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemYearsOfExperienceType0):
            years_of_experience = self.years_of_experience.to_dict()
        else:
            years_of_experience = self.years_of_experience

        geo_location: Union[None, Unset, dict[str, Any]]
        if isinstance(self.geo_location, Unset):
            geo_location = UNSET
        elif isinstance(self.geo_location, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0):
            geo_location = self.geo_location.to_dict()
        else:
            geo_location = self.geo_location

        country_or_region_code: Union[None, Unset, list[str]]
        if isinstance(self.country_or_region_code, Unset):
            country_or_region_code = UNSET
        elif isinstance(self.country_or_region_code, list):
            country_or_region_code = []
            for country_or_region_code_type_0_item_data in self.country_or_region_code:
                country_or_region_code_type_0_item = country_or_region_code_type_0_item_data.value
                country_or_region_code.append(country_or_region_code_type_0_item)


        else:
            country_or_region_code = self.country_or_region_code

        seniority: Union[None, Unset, list[str]]
        if isinstance(self.seniority, Unset):
            seniority = UNSET
        elif isinstance(self.seniority, list):
            seniority = []
            for seniority_type_0_item_data in self.seniority:
                seniority_type_0_item = seniority_type_0_item_data.value
                seniority.append(seniority_type_0_item)


        else:
            seniority = self.seniority

        employment_type: Union[None, Unset, list[str]]
        if isinstance(self.employment_type, Unset):
            employment_type = UNSET
        elif isinstance(self.employment_type, list):
            employment_type = []
            for employment_type_type_0_item_data in self.employment_type:
                employment_type_type_0_item = employment_type_type_0_item_data.value
                employment_type.append(employment_type_type_0_item)


        else:
            employment_type = self.employment_type

        job_function: Union[None, Unset, list[str]]
        if isinstance(self.job_function, Unset):
            job_function = UNSET
        elif isinstance(self.job_function, list):
            job_function = []
            for job_function_type_0_item_data in self.job_function:
                job_function_type_0_item = job_function_type_0_item_data.value
                job_function.append(job_function_type_0_item)


        else:
            job_function = self.job_function

        industry: Union[None, Unset, list[str]]
        if isinstance(self.industry, Unset):
            industry = UNSET
        elif isinstance(self.industry, list):
            industry = []
            for industry_type_0_item_data in self.industry:
                industry_type_0_item = industry_type_0_item_data.value
                industry.append(industry_type_0_item)


        else:
            industry = self.industry

        job_location_type: Union[None, Unset, list[str]]
        if isinstance(self.job_location_type, Unset):
            job_location_type = UNSET
        elif isinstance(self.job_location_type, list):
            job_location_type = []
            for job_location_type_type_0_item_data in self.job_location_type:
                job_location_type_type_0_item = job_location_type_type_0_item_data.value
                job_location_type.append(job_location_type_type_0_item)


        else:
            job_location_type = self.job_location_type


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if job_posting_status is not UNSET:
            field_dict["jobPostingStatus"] = job_posting_status
        if job_title is not UNSET:
            field_dict["jobTitle"] = job_title
        if keywords is not UNSET:
            field_dict["keywords"] = keywords
        if posted_at is not UNSET:
            field_dict["postedAt"] = posted_at
        if num_applicants is not UNSET:
            field_dict["numApplicants"] = num_applicants
        if annual_pay_usd is not UNSET:
            field_dict["annualPayUSD"] = annual_pay_usd
        if years_of_experience is not UNSET:
            field_dict["yearsOfExperience"] = years_of_experience
        if geo_location is not UNSET:
            field_dict["geoLocation"] = geo_location
        if country_or_region_code is not UNSET:
            field_dict["countryOrRegionCode"] = country_or_region_code
        if seniority is not UNSET:
            field_dict["seniority"] = seniority
        if employment_type is not UNSET:
            field_dict["employmentType"] = employment_type
        if job_function is not UNSET:
            field_dict["jobFunction"] = job_function
        if industry is not UNSET:
            field_dict["industry"] = industry
        if job_location_type is not UNSET:
            field_dict["jobLocationType"] = job_location_type

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_annual_pay_usd_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemAnnualPayUSDType0
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_num_applicants_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemNumApplicantsType0
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_geo_location_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType0
        from ..models.company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item_years_of_experience_type_0 import CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemYearsOfExperienceType0
        d = dict(src_dict)
        def _parse_job_posting_status(data: object) -> Union[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType1, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType2Type1, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType3Type1, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                job_posting_status_type_1 = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType1(data)



                return job_posting_status_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                job_posting_status_type_2_type_1 = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType2Type1(data)



                return job_posting_status_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                job_posting_status_type_3_type_1 = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType3Type1(data)



                return job_posting_status_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType1, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType2Type1, CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobPostingStatusType3Type1, None, Unset], data)

        job_posting_status = _parse_job_posting_status(d.pop("jobPostingStatus", UNSET))


        def _parse_job_title(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                job_title_type_0 = cast(list[str], data)

                return job_title_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        job_title = _parse_job_title(d.pop("jobTitle", UNSET))


        def _parse_keywords(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                keywords_type_0 = cast(list[str], data)

                return keywords_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        keywords = _parse_keywords(d.pop("keywords", UNSET))


        def _parse_posted_at(data: object) -> Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType0', 'CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                posted_at_type_0 = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType0.from_dict(data)



                return posted_at_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                posted_at_type_1 = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1.from_dict(data)



                return posted_at_type_1
            except: # noqa: E722
                pass
            return cast(Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType0', 'CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1', None, Unset], data)

        posted_at = _parse_posted_at(d.pop("postedAt", UNSET))


        def _parse_num_applicants(data: object) -> Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemNumApplicantsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                num_applicants_type_0 = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemNumApplicantsType0.from_dict(data)



                return num_applicants_type_0
            except: # noqa: E722
                pass
            return cast(Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemNumApplicantsType0', None, Unset], data)

        num_applicants = _parse_num_applicants(d.pop("numApplicants", UNSET))


        def _parse_annual_pay_usd(data: object) -> Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemAnnualPayUSDType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                annual_pay_usd_type_0 = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemAnnualPayUSDType0.from_dict(data)



                return annual_pay_usd_type_0
            except: # noqa: E722
                pass
            return cast(Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemAnnualPayUSDType0', None, Unset], data)

        annual_pay_usd = _parse_annual_pay_usd(d.pop("annualPayUSD", UNSET))


        def _parse_years_of_experience(data: object) -> Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemYearsOfExperienceType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                years_of_experience_type_0 = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemYearsOfExperienceType0.from_dict(data)



                return years_of_experience_type_0
            except: # noqa: E722
                pass
            return cast(Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemYearsOfExperienceType0', None, Unset], data)

        years_of_experience = _parse_years_of_experience(d.pop("yearsOfExperience", UNSET))


        def _parse_geo_location(data: object) -> Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                geo_location_type_0 = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0.from_dict(data)



                return geo_location_type_0
            except: # noqa: E722
                pass
            return cast(Union['CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0', None, Unset], data)

        geo_location = _parse_geo_location(d.pop("geoLocation", UNSET))


        def _parse_country_or_region_code(data: object) -> Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemCountryOrRegionCodeType0Item]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                country_or_region_code_type_0 = []
                _country_or_region_code_type_0 = data
                for country_or_region_code_type_0_item_data in (_country_or_region_code_type_0):
                    country_or_region_code_type_0_item = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemCountryOrRegionCodeType0Item(country_or_region_code_type_0_item_data)



                    country_or_region_code_type_0.append(country_or_region_code_type_0_item)

                return country_or_region_code_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemCountryOrRegionCodeType0Item]], data)

        country_or_region_code = _parse_country_or_region_code(d.pop("countryOrRegionCode", UNSET))


        def _parse_seniority(data: object) -> Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemSeniorityType0Item]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                seniority_type_0 = []
                _seniority_type_0 = data
                for seniority_type_0_item_data in (_seniority_type_0):
                    seniority_type_0_item = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemSeniorityType0Item(seniority_type_0_item_data)



                    seniority_type_0.append(seniority_type_0_item)

                return seniority_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemSeniorityType0Item]], data)

        seniority = _parse_seniority(d.pop("seniority", UNSET))


        def _parse_employment_type(data: object) -> Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemEmploymentTypeType0Item]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                employment_type_type_0 = []
                _employment_type_type_0 = data
                for employment_type_type_0_item_data in (_employment_type_type_0):
                    employment_type_type_0_item = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemEmploymentTypeType0Item(employment_type_type_0_item_data)



                    employment_type_type_0.append(employment_type_type_0_item)

                return employment_type_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemEmploymentTypeType0Item]], data)

        employment_type = _parse_employment_type(d.pop("employmentType", UNSET))


        def _parse_job_function(data: object) -> Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobFunctionType0Item]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                job_function_type_0 = []
                _job_function_type_0 = data
                for job_function_type_0_item_data in (_job_function_type_0):
                    job_function_type_0_item = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobFunctionType0Item(job_function_type_0_item_data)



                    job_function_type_0.append(job_function_type_0_item)

                return job_function_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobFunctionType0Item]], data)

        job_function = _parse_job_function(d.pop("jobFunction", UNSET))


        def _parse_industry(data: object) -> Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemIndustryType0Item]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                industry_type_0 = []
                _industry_type_0 = data
                for industry_type_0_item_data in (_industry_type_0):
                    industry_type_0_item = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemIndustryType0Item(industry_type_0_item_data)



                    industry_type_0.append(industry_type_0_item)

                return industry_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemIndustryType0Item]], data)

        industry = _parse_industry(d.pop("industry", UNSET))


        def _parse_job_location_type(data: object) -> Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobLocationTypeType0Item]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                job_location_type_type_0 = []
                _job_location_type_type_0 = data
                for job_location_type_type_0_item_data in (_job_location_type_type_0):
                    job_location_type_type_0_item = CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobLocationTypeType0Item(job_location_type_type_0_item_data)



                    job_location_type_type_0.append(job_location_type_type_0_item)

                return job_location_type_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[CompanyCountBodySearchParamsJobPostingsV2Type0AnyOfType0ItemJobLocationTypeType0Item]], data)

        job_location_type = _parse_job_location_type(d.pop("jobLocationType", UNSET))


        company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item = cls(
            job_posting_status=job_posting_status,
            job_title=job_title,
            keywords=keywords,
            posted_at=posted_at,
            num_applicants=num_applicants,
            annual_pay_usd=annual_pay_usd,
            years_of_experience=years_of_experience,
            geo_location=geo_location,
            country_or_region_code=country_or_region_code,
            seniority=seniority,
            employment_type=employment_type,
            job_function=job_function,
            industry=industry,
            job_location_type=job_location_type,
        )


        company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item.additional_properties = d
        return company_count_body_search_params_job_postings_v2_type_0_any_of_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import IntEnum

class CompanySearchBodySearchParamsEmployeeCountV2Type0LowerBoundExclusiveType8(IntEnum):
    VALUE_10000 = 10000

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType0CompanySearchParamsNaicsCodesType0NoneOfType0Item")



@_attrs_define
class CreateSavedSearchBodySearchParamsType0CompanySearchParamsNaicsCodesType0NoneOfType0Item:
    """ 
        Attributes:
            code (str):
            title (str):
     """

    code: str
    title: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        code = self.code

        title = self.title


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "code": code,
            "title": title,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        code = d.pop("code")

        title = d.pop("title")

        create_saved_search_body_search_params_type_0_company_search_params_naics_codes_type_0_none_of_type_0_item = cls(
            code=code,
            title=title,
        )


        create_saved_search_body_search_params_type_0_company_search_params_naics_codes_type_0_none_of_type_0_item.additional_properties = d
        return create_saved_search_body_search_params_type_0_company_search_params_naics_codes_type_0_none_of_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.sync_combined_search_response_200_output_companies_item_num_matching_locations_type_0_matched_offices_item_location_type_0 import SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0





T = TypeVar("T", bound="SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItem")



@_attrs_define
class SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItem:
    """ 
        Attributes:
            address (Union[None, Unset, str]):
            is_primary (Union[None, Unset, bool]):
            location (Union['SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLoca
                tionType0', None, Unset]):
     """

    address: Union[None, Unset, str] = UNSET
    is_primary: Union[None, Unset, bool] = UNSET
    location: Union['SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.sync_combined_search_response_200_output_companies_item_num_matching_locations_type_0_matched_offices_item_location_type_0 import SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0
        address: Union[None, Unset, str]
        if isinstance(self.address, Unset):
            address = UNSET
        else:
            address = self.address

        is_primary: Union[None, Unset, bool]
        if isinstance(self.is_primary, Unset):
            is_primary = UNSET
        else:
            is_primary = self.is_primary

        location: Union[None, Unset, dict[str, Any]]
        if isinstance(self.location, Unset):
            location = UNSET
        elif isinstance(self.location, SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0):
            location = self.location.to_dict()
        else:
            location = self.location


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if address is not UNSET:
            field_dict["address"] = address
        if is_primary is not UNSET:
            field_dict["is_primary"] = is_primary
        if location is not UNSET:
            field_dict["location"] = location

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sync_combined_search_response_200_output_companies_item_num_matching_locations_type_0_matched_offices_item_location_type_0 import SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0
        d = dict(src_dict)
        def _parse_address(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        address = _parse_address(d.pop("address", UNSET))


        def _parse_is_primary(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        is_primary = _parse_is_primary(d.pop("is_primary", UNSET))


        def _parse_location(data: object) -> Union['SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                location_type_0 = SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0.from_dict(data)



                return location_type_0
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchResponse200OutputCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0', None, Unset], data)

        location = _parse_location(d.pop("location", UNSET))


        sync_combined_search_response_200_output_companies_item_num_matching_locations_type_0_matched_offices_item = cls(
            address=address,
            is_primary=is_primary,
            location=location,
        )


        sync_combined_search_response_200_output_companies_item_num_matching_locations_type_0_matched_offices_item.additional_properties = d
        return sync_combined_search_response_200_output_companies_item_num_matching_locations_type_0_matched_offices_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item_hired_at_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType0
  from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item_hired_at_type_1 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1





T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item")



@_attrs_define
class CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item:
    """ 
        Attributes:
            hired_at (Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFilters
                Type0RecentlyHiredType0ItemHiredAtType0', 'CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesTyp
                e0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1', None, Unset]):
            job_title (Union[None, Unset, list[str]]):
     """

    hired_at: Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType0', 'CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1', None, Unset] = UNSET
    job_title: Union[None, Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item_hired_at_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType0
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item_hired_at_type_1 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1
        hired_at: Union[None, Unset, dict[str, Any]]
        if isinstance(self.hired_at, Unset):
            hired_at = UNSET
        elif isinstance(self.hired_at, CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType0):
            hired_at = self.hired_at.to_dict()
        elif isinstance(self.hired_at, CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1):
            hired_at = self.hired_at.to_dict()
        else:
            hired_at = self.hired_at

        job_title: Union[None, Unset, list[str]]
        if isinstance(self.job_title, Unset):
            job_title = UNSET
        elif isinstance(self.job_title, list):
            job_title = self.job_title


        else:
            job_title = self.job_title


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if hired_at is not UNSET:
            field_dict["hiredAt"] = hired_at
        if job_title is not UNSET:
            field_dict["jobTitle"] = job_title

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item_hired_at_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType0
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item_hired_at_type_1 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1
        d = dict(src_dict)
        def _parse_hired_at(data: object) -> Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType0', 'CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                hired_at_type_0 = CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType0.from_dict(data)



                return hired_at_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                hired_at_type_1 = CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1.from_dict(data)



                return hired_at_type_1
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType0', 'CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1', None, Unset], data)

        hired_at = _parse_hired_at(d.pop("hiredAt", UNSET))


        def _parse_job_title(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                job_title_type_0 = cast(list[str], data)

                return job_title_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        job_title = _parse_job_title(d.pop("jobTitle", UNSET))


        create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item = cls(
            hired_at=hired_at,
            job_title=job_title,
        )


        create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item.additional_properties = d
        return create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.post_reactions_live_fetch_response_200_output_data_item_reaction_type_type_1 import PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType1
from ..models.post_reactions_live_fetch_response_200_output_data_item_reaction_type_type_2_type_1 import PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType2Type1
from ..models.post_reactions_live_fetch_response_200_output_data_item_reaction_type_type_3_type_1 import PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType3Type1
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.post_reactions_live_fetch_response_200_output_data_item_reactor_type_0 import PostReactionsLiveFetchResponse200OutputDataItemReactorType0





T = TypeVar("T", bound="PostReactionsLiveFetchResponse200OutputDataItem")



@_attrs_define
class PostReactionsLiveFetchResponse200OutputDataItem:
    """ 
        Attributes:
            reaction_type (Union[None, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType1,
                PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType2Type1,
                PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType3Type1, Unset]): One of LinkedIn's reaction
                types. These match the tooltips on each of LinkedIn's six reaction buttons; for instance, 'Like' is the blue
                thumbs-up.
            reactor (Union['PostReactionsLiveFetchResponse200OutputDataItemReactorType0', None, Unset]):
     """

    reaction_type: Union[None, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType1, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType2Type1, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType3Type1, Unset] = UNSET
    reactor: Union['PostReactionsLiveFetchResponse200OutputDataItemReactorType0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.post_reactions_live_fetch_response_200_output_data_item_reactor_type_0 import PostReactionsLiveFetchResponse200OutputDataItemReactorType0
        reaction_type: Union[None, Unset, str]
        if isinstance(self.reaction_type, Unset):
            reaction_type = UNSET
        elif isinstance(self.reaction_type, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType1):
            reaction_type = self.reaction_type.value
        elif isinstance(self.reaction_type, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType2Type1):
            reaction_type = self.reaction_type.value
        elif isinstance(self.reaction_type, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType3Type1):
            reaction_type = self.reaction_type.value
        else:
            reaction_type = self.reaction_type

        reactor: Union[None, Unset, dict[str, Any]]
        if isinstance(self.reactor, Unset):
            reactor = UNSET
        elif isinstance(self.reactor, PostReactionsLiveFetchResponse200OutputDataItemReactorType0):
            reactor = self.reactor.to_dict()
        else:
            reactor = self.reactor


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if reaction_type is not UNSET:
            field_dict["reactionType"] = reaction_type
        if reactor is not UNSET:
            field_dict["reactor"] = reactor

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.post_reactions_live_fetch_response_200_output_data_item_reactor_type_0 import PostReactionsLiveFetchResponse200OutputDataItemReactorType0
        d = dict(src_dict)
        def _parse_reaction_type(data: object) -> Union[None, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType1, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType2Type1, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                reaction_type_type_1 = PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType1(data)



                return reaction_type_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                reaction_type_type_2_type_1 = PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType2Type1(data)



                return reaction_type_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                reaction_type_type_3_type_1 = PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType3Type1(data)



                return reaction_type_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[None, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType1, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType2Type1, PostReactionsLiveFetchResponse200OutputDataItemReactionTypeType3Type1, Unset], data)

        reaction_type = _parse_reaction_type(d.pop("reactionType", UNSET))


        def _parse_reactor(data: object) -> Union['PostReactionsLiveFetchResponse200OutputDataItemReactorType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                reactor_type_0 = PostReactionsLiveFetchResponse200OutputDataItemReactorType0.from_dict(data)



                return reactor_type_0
            except: # noqa: E722
                pass
            return cast(Union['PostReactionsLiveFetchResponse200OutputDataItemReactorType0', None, Unset], data)

        reactor = _parse_reactor(d.pop("reactor", UNSET))


        post_reactions_live_fetch_response_200_output_data_item = cls(
            reaction_type=reaction_type,
            reactor=reactor,
        )


        post_reactions_live_fetch_response_200_output_data_item.additional_properties = d
        return post_reactions_live_fetch_response_200_output_data_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class KitchenSinkBulkProfileBodyProfilesItemCompanyIdentifierType2Identifier(str, Enum):
    LINKEDINORGID = "linkedinOrgID"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TextToCombinedSearchResponse200OutputProfileSearchParamsType0LocationType0SubtractAllType0ItemType0RadiusType1Unit(str, Enum):
    KILOMETERS = "kilometers"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class ProfileLiveEnrichResponse200ProfileFoundAndEnrichedProfileExperiencesType0ItemJobFunctionType0Item(str, Enum):
    ACCOUNTING = "Accounting"
    ADMINISTRATIVE = "Administrative"
    ADVERTISING = "Advertising"
    ANALYST = "Analyst"
    ARTS_AND_DESIGN = "Arts and Design"
    ART_CREATIVE = "Art / Creative"
    BUSINESS_DEVELOPMENT = "Business Development"
    COMMUNITY_SOCIAL_SERVICES = "Community & Social Services"
    CONSULTING = "Consulting"
    CUSTOMER_SERVICE = "Customer Service"
    DESIGN = "Design"
    DISTRIBUTION = "Distribution"
    EDUCATION = "Education"
    ENGINEERING = "Engineering"
    ENTREPRENEURSHIP = "Entrepreneurship"
    FINANCE = "Finance"
    GENERAL_BUSINESS = "General Business"
    HEALTHCARE_SERVICES = "Healthcare Services"
    HEALTH_CARE_PROVIDER = "Health Care Provider"
    HUMAN_RESOURCES = "Human Resources"
    INFORMATION_TECHNOLOGY = "Information Technology"
    LEGAL = "Legal"
    MANAGEMENT = "Management"
    MANUFACTURING = "Manufacturing"
    MARKETING = "Marketing"
    MILITARY_PROTECTIVE_SERVICES = "Military & Protective Services"
    OPERATIONS = "Operations"
    OTHER = "Other"
    PRODUCTION = "Production"
    PRODUCT_MANAGEMENT = "Product Management"
    PROGRAM_PRODUCT_MANAGEMENT = "Program & Product Management"
    PROJECT_MANAGEMENT = "Project Management"
    PUBLIC_RELATIONS = "Public Relations"
    PURCHASING = "Purchasing"
    QUALITY_ASSURANCE = "Quality Assurance"
    REAL_ESTATE = "Real Estate"
    RESEARCH = "Research"
    SALES = "Sales"
    SCIENCE = "Science"
    STRATEGY_PLANNING = "Strategy / Planning"
    SUPPLY_CHAIN = "Supply Chain"
    SUPPORT = "Support"
    TRAINING = "Training"
    WRITING_EDITING = "Writing / Editing"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.text_to_combined_search_response_200_output_data_companies_item_num_matching_locations_type_0_matched_offices_item_location_type_0_coordinates_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0





T = TypeVar("T", bound="TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0")



@_attrs_define
class TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0:
    """ 
        Attributes:
            street_address (Union[None, Unset, str]):
            neighborhood (Union[None, Unset, str]):
            city (Union[None, Unset, str]):
            state_name (Union[None, Unset, str]):
            state_code (Union[None, Unset, str]):
            county (Union[None, Unset, str]):
            postal_code (Union[None, Unset, str]):
            country_code (Union[None, Unset, str]):
            country_name (Union[None, Unset, str]):
            coordinates (Union['TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOffice
                sItemLocationType0CoordinatesType0', None, Unset]):
            timezone (Union[None, Unset, str]):
            full_address (Union[None, Unset, str]):
            formatted_address (Union[None, Unset, str]):
     """

    street_address: Union[None, Unset, str] = UNSET
    neighborhood: Union[None, Unset, str] = UNSET
    city: Union[None, Unset, str] = UNSET
    state_name: Union[None, Unset, str] = UNSET
    state_code: Union[None, Unset, str] = UNSET
    county: Union[None, Unset, str] = UNSET
    postal_code: Union[None, Unset, str] = UNSET
    country_code: Union[None, Unset, str] = UNSET
    country_name: Union[None, Unset, str] = UNSET
    coordinates: Union['TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0', None, Unset] = UNSET
    timezone: Union[None, Unset, str] = UNSET
    full_address: Union[None, Unset, str] = UNSET
    formatted_address: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.text_to_combined_search_response_200_output_data_companies_item_num_matching_locations_type_0_matched_offices_item_location_type_0_coordinates_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0
        street_address: Union[None, Unset, str]
        if isinstance(self.street_address, Unset):
            street_address = UNSET
        else:
            street_address = self.street_address

        neighborhood: Union[None, Unset, str]
        if isinstance(self.neighborhood, Unset):
            neighborhood = UNSET
        else:
            neighborhood = self.neighborhood

        city: Union[None, Unset, str]
        if isinstance(self.city, Unset):
            city = UNSET
        else:
            city = self.city

        state_name: Union[None, Unset, str]
        if isinstance(self.state_name, Unset):
            state_name = UNSET
        else:
            state_name = self.state_name

        state_code: Union[None, Unset, str]
        if isinstance(self.state_code, Unset):
            state_code = UNSET
        else:
            state_code = self.state_code

        county: Union[None, Unset, str]
        if isinstance(self.county, Unset):
            county = UNSET
        else:
            county = self.county

        postal_code: Union[None, Unset, str]
        if isinstance(self.postal_code, Unset):
            postal_code = UNSET
        else:
            postal_code = self.postal_code

        country_code: Union[None, Unset, str]
        if isinstance(self.country_code, Unset):
            country_code = UNSET
        else:
            country_code = self.country_code

        country_name: Union[None, Unset, str]
        if isinstance(self.country_name, Unset):
            country_name = UNSET
        else:
            country_name = self.country_name

        coordinates: Union[None, Unset, dict[str, Any]]
        if isinstance(self.coordinates, Unset):
            coordinates = UNSET
        elif isinstance(self.coordinates, TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0):
            coordinates = self.coordinates.to_dict()
        else:
            coordinates = self.coordinates

        timezone: Union[None, Unset, str]
        if isinstance(self.timezone, Unset):
            timezone = UNSET
        else:
            timezone = self.timezone

        full_address: Union[None, Unset, str]
        if isinstance(self.full_address, Unset):
            full_address = UNSET
        else:
            full_address = self.full_address

        formatted_address: Union[None, Unset, str]
        if isinstance(self.formatted_address, Unset):
            formatted_address = UNSET
        else:
            formatted_address = self.formatted_address


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if street_address is not UNSET:
            field_dict["street_address"] = street_address
        if neighborhood is not UNSET:
            field_dict["neighborhood"] = neighborhood
        if city is not UNSET:
            field_dict["city"] = city
        if state_name is not UNSET:
            field_dict["state_name"] = state_name
        if state_code is not UNSET:
            field_dict["state_code"] = state_code
        if county is not UNSET:
            field_dict["county"] = county
        if postal_code is not UNSET:
            field_dict["postal_code"] = postal_code
        if country_code is not UNSET:
            field_dict["country_code"] = country_code
        if country_name is not UNSET:
            field_dict["country_name"] = country_name
        if coordinates is not UNSET:
            field_dict["coordinates"] = coordinates
        if timezone is not UNSET:
            field_dict["timezone"] = timezone
        if full_address is not UNSET:
            field_dict["full_address"] = full_address
        if formatted_address is not UNSET:
            field_dict["formatted_address"] = formatted_address

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.text_to_combined_search_response_200_output_data_companies_item_num_matching_locations_type_0_matched_offices_item_location_type_0_coordinates_type_0 import TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0
        d = dict(src_dict)
        def _parse_street_address(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        street_address = _parse_street_address(d.pop("street_address", UNSET))


        def _parse_neighborhood(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        neighborhood = _parse_neighborhood(d.pop("neighborhood", UNSET))


        def _parse_city(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        city = _parse_city(d.pop("city", UNSET))


        def _parse_state_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        state_name = _parse_state_name(d.pop("state_name", UNSET))


        def _parse_state_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        state_code = _parse_state_code(d.pop("state_code", UNSET))


        def _parse_county(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        county = _parse_county(d.pop("county", UNSET))


        def _parse_postal_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        postal_code = _parse_postal_code(d.pop("postal_code", UNSET))


        def _parse_country_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country_code = _parse_country_code(d.pop("country_code", UNSET))


        def _parse_country_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country_name = _parse_country_name(d.pop("country_name", UNSET))


        def _parse_coordinates(data: object) -> Union['TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                coordinates_type_0 = TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0.from_dict(data)



                return coordinates_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataCompaniesItemNumMatchingLocationsType0MatchedOfficesItemLocationType0CoordinatesType0', None, Unset], data)

        coordinates = _parse_coordinates(d.pop("coordinates", UNSET))


        def _parse_timezone(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        timezone = _parse_timezone(d.pop("timezone", UNSET))


        def _parse_full_address(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        full_address = _parse_full_address(d.pop("full_address", UNSET))


        def _parse_formatted_address(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        formatted_address = _parse_formatted_address(d.pop("formatted_address", UNSET))


        text_to_combined_search_response_200_output_data_companies_item_num_matching_locations_type_0_matched_offices_item_location_type_0 = cls(
            street_address=street_address,
            neighborhood=neighborhood,
            city=city,
            state_name=state_name,
            state_code=state_code,
            county=county,
            postal_code=postal_code,
            country_code=country_code,
            country_name=country_name,
            coordinates=coordinates,
            timezone=timezone,
            full_address=full_address,
            formatted_address=formatted_address,
        )


        text_to_combined_search_response_200_output_data_companies_item_num_matching_locations_type_0_matched_offices_item_location_type_0.additional_properties = d
        return text_to_combined_search_response_200_output_data_companies_item_num_matching_locations_type_0_matched_offices_item_location_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="TextToCombinedSearchResponse200OutputDataCompaniesItemInvestmentStatsType0InvestmentsByStageType0Item")



@_attrs_define
class TextToCombinedSearchResponse200OutputDataCompaniesItemInvestmentStatsType0InvestmentsByStageType0Item:
    """ 
        Attributes:
            stage (Union[None, Unset, str]):
            lead_rate (Union[None, Unset, float]):
            lead_count (Union[None, Unset, float]):
            total_count (Union[None, Unset, float]):
            share_of_portfolio (Union[None, Unset, float]):
            last_investment_date (Union[None, Unset, str]):
     """

    stage: Union[None, Unset, str] = UNSET
    lead_rate: Union[None, Unset, float] = UNSET
    lead_count: Union[None, Unset, float] = UNSET
    total_count: Union[None, Unset, float] = UNSET
    share_of_portfolio: Union[None, Unset, float] = UNSET
    last_investment_date: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        stage: Union[None, Unset, str]
        if isinstance(self.stage, Unset):
            stage = UNSET
        else:
            stage = self.stage

        lead_rate: Union[None, Unset, float]
        if isinstance(self.lead_rate, Unset):
            lead_rate = UNSET
        else:
            lead_rate = self.lead_rate

        lead_count: Union[None, Unset, float]
        if isinstance(self.lead_count, Unset):
            lead_count = UNSET
        else:
            lead_count = self.lead_count

        total_count: Union[None, Unset, float]
        if isinstance(self.total_count, Unset):
            total_count = UNSET
        else:
            total_count = self.total_count

        share_of_portfolio: Union[None, Unset, float]
        if isinstance(self.share_of_portfolio, Unset):
            share_of_portfolio = UNSET
        else:
            share_of_portfolio = self.share_of_portfolio

        last_investment_date: Union[None, Unset, str]
        if isinstance(self.last_investment_date, Unset):
            last_investment_date = UNSET
        else:
            last_investment_date = self.last_investment_date


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if stage is not UNSET:
            field_dict["stage"] = stage
        if lead_rate is not UNSET:
            field_dict["lead_rate"] = lead_rate
        if lead_count is not UNSET:
            field_dict["lead_count"] = lead_count
        if total_count is not UNSET:
            field_dict["total_count"] = total_count
        if share_of_portfolio is not UNSET:
            field_dict["share_of_portfolio"] = share_of_portfolio
        if last_investment_date is not UNSET:
            field_dict["last_investment_date"] = last_investment_date

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_stage(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        stage = _parse_stage(d.pop("stage", UNSET))


        def _parse_lead_rate(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lead_rate = _parse_lead_rate(d.pop("lead_rate", UNSET))


        def _parse_lead_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        lead_count = _parse_lead_count(d.pop("lead_count", UNSET))


        def _parse_total_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        total_count = _parse_total_count(d.pop("total_count", UNSET))


        def _parse_share_of_portfolio(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        share_of_portfolio = _parse_share_of_portfolio(d.pop("share_of_portfolio", UNSET))


        def _parse_last_investment_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        last_investment_date = _parse_last_investment_date(d.pop("last_investment_date", UNSET))


        text_to_combined_search_response_200_output_data_companies_item_investment_stats_type_0_investments_by_stage_type_0_item = cls(
            stage=stage,
            lead_rate=lead_rate,
            lead_count=lead_count,
            total_count=total_count,
            share_of_portfolio=share_of_portfolio,
            last_investment_date=last_investment_date,
        )


        text_to_combined_search_response_200_output_data_companies_item_investment_stats_type_0_investments_by_stage_type_0_item.additional_properties = d
        return text_to_combined_search_response_200_output_data_companies_item_investment_stats_type_0_investments_by_stage_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.investor_search_response_200_output_investors_item_recent_investments_type_0_item_round_type_type_1 import InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType1
from ..models.investor_search_response_200_output_investors_item_recent_investments_type_0_item_round_type_type_2_type_1 import InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType2Type1
from ..models.investor_search_response_200_output_investors_item_recent_investments_type_0_item_round_type_type_3_type_1 import InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType3Type1
from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0Item")



@_attrs_define
class InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0Item:
    """ 
        Attributes:
            was_lead_investor (bool): Whether the investor was lead investor
            org_linkedin_slug (Union[None, Unset, str]): LinkedIn slug for the organization invested in (in long format,
                e.g., 'company/companyname')
            org_name (Union[None, Unset, str]): Name of the organization invested in
            org_domain (Union[None, Unset, str]): Domain of the organization
            round_type (Union[InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType1,
                InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType2Type1,
                InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType3Type1, None, Unset]): Type
                of funding round (e.g., series_a, seed)
            round_date (Union[None, Unset, str]): Date of the funding round
            round_raised_usd (Union[None, Unset, int]): Amount raised in USD
     """

    was_lead_investor: bool
    org_linkedin_slug: Union[None, Unset, str] = UNSET
    org_name: Union[None, Unset, str] = UNSET
    org_domain: Union[None, Unset, str] = UNSET
    round_type: Union[InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType1, InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType2Type1, InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType3Type1, None, Unset] = UNSET
    round_date: Union[None, Unset, str] = UNSET
    round_raised_usd: Union[None, Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        was_lead_investor = self.was_lead_investor

        org_linkedin_slug: Union[None, Unset, str]
        if isinstance(self.org_linkedin_slug, Unset):
            org_linkedin_slug = UNSET
        else:
            org_linkedin_slug = self.org_linkedin_slug

        org_name: Union[None, Unset, str]
        if isinstance(self.org_name, Unset):
            org_name = UNSET
        else:
            org_name = self.org_name

        org_domain: Union[None, Unset, str]
        if isinstance(self.org_domain, Unset):
            org_domain = UNSET
        else:
            org_domain = self.org_domain

        round_type: Union[None, Unset, str]
        if isinstance(self.round_type, Unset):
            round_type = UNSET
        elif isinstance(self.round_type, InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType1):
            round_type = self.round_type.value
        elif isinstance(self.round_type, InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType2Type1):
            round_type = self.round_type.value
        elif isinstance(self.round_type, InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType3Type1):
            round_type = self.round_type.value
        else:
            round_type = self.round_type

        round_date: Union[None, Unset, str]
        if isinstance(self.round_date, Unset):
            round_date = UNSET
        else:
            round_date = self.round_date

        round_raised_usd: Union[None, Unset, int]
        if isinstance(self.round_raised_usd, Unset):
            round_raised_usd = UNSET
        else:
            round_raised_usd = self.round_raised_usd


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "wasLeadInvestor": was_lead_investor,
        })
        if org_linkedin_slug is not UNSET:
            field_dict["orgLinkedinSlug"] = org_linkedin_slug
        if org_name is not UNSET:
            field_dict["orgName"] = org_name
        if org_domain is not UNSET:
            field_dict["orgDomain"] = org_domain
        if round_type is not UNSET:
            field_dict["roundType"] = round_type
        if round_date is not UNSET:
            field_dict["roundDate"] = round_date
        if round_raised_usd is not UNSET:
            field_dict["roundRaisedUSD"] = round_raised_usd

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        was_lead_investor = d.pop("wasLeadInvestor")

        def _parse_org_linkedin_slug(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        org_linkedin_slug = _parse_org_linkedin_slug(d.pop("orgLinkedinSlug", UNSET))


        def _parse_org_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        org_name = _parse_org_name(d.pop("orgName", UNSET))


        def _parse_org_domain(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        org_domain = _parse_org_domain(d.pop("orgDomain", UNSET))


        def _parse_round_type(data: object) -> Union[InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType1, InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType2Type1, InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType3Type1, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                round_type_type_1 = InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType1(data)



                return round_type_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                round_type_type_2_type_1 = InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType2Type1(data)



                return round_type_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                round_type_type_3_type_1 = InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType3Type1(data)



                return round_type_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType1, InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType2Type1, InvestorSearchResponse200OutputInvestorsItemRecentInvestmentsType0ItemRoundTypeType3Type1, None, Unset], data)

        round_type = _parse_round_type(d.pop("roundType", UNSET))


        def _parse_round_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_date = _parse_round_date(d.pop("roundDate", UNSET))


        def _parse_round_raised_usd(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        round_raised_usd = _parse_round_raised_usd(d.pop("roundRaisedUSD", UNSET))


        investor_search_response_200_output_investors_item_recent_investments_type_0_item = cls(
            was_lead_investor=was_lead_investor,
            org_linkedin_slug=org_linkedin_slug,
            org_name=org_name,
            org_domain=org_domain,
            round_type=round_type,
            round_date=round_date,
            round_raised_usd=round_raised_usd,
        )


        investor_search_response_200_output_investors_item_recent_investments_type_0_item.additional_properties = d
        return investor_search_response_200_output_investors_item_recent_investments_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0AnyOfType0ItemType1Rule(str, Enum):
    COUNTRY = "country"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.job_posting_search_response_200_output_data_item_compensation_range_type_0_lte_type_0_period import JobPostingSearchResponse200OutputDataItemCompensationRangeType0LteType0Period






T = TypeVar("T", bound="JobPostingSearchResponse200OutputDataItemCompensationRangeType0LteType0")



@_attrs_define
class JobPostingSearchResponse200OutputDataItemCompensationRangeType0LteType0:
    """ 
        Attributes:
            currency_unit (str): These are just currency symbols, like CA$ or £
            number (float):
            period (JobPostingSearchResponse200OutputDataItemCompensationRangeType0LteType0Period):
     """

    currency_unit: str
    number: float
    period: JobPostingSearchResponse200OutputDataItemCompensationRangeType0LteType0Period
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        currency_unit = self.currency_unit

        number = self.number

        period = self.period.value


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "currencyUnit": currency_unit,
            "number": number,
            "period": period,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        currency_unit = d.pop("currencyUnit")

        number = d.pop("number")

        period = JobPostingSearchResponse200OutputDataItemCompensationRangeType0LteType0Period(d.pop("period"))




        job_posting_search_response_200_output_data_item_compensation_range_type_0_lte_type_0 = cls(
            currency_unit=currency_unit,
            number=number,
            period=period,
        )


        job_posting_search_response_200_output_data_item_compensation_range_type_0_lte_type_0.additional_properties = d
        return job_posting_search_response_200_output_data_item_compensation_range_type_0_lte_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CompanyCountBodySearchParamsJobPostingStatsType0AllOfType0ItemType5Rule(str, Enum):
    LOCATION_TYPE = "location-type"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="CombinedSearchBodyProfileParamsExactProfileType0NoneOfType0Item")



@_attrs_define
class CombinedSearchBodyProfileParamsExactProfileType0NoneOfType0Item:
    """ 
        Attributes:
            profile_id (Union[None, Unset, str]):
            primary_slug (Union[None, Unset, str]):
     """

    profile_id: Union[None, Unset, str] = UNSET
    primary_slug: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        profile_id: Union[None, Unset, str]
        if isinstance(self.profile_id, Unset):
            profile_id = UNSET
        else:
            profile_id = self.profile_id

        primary_slug: Union[None, Unset, str]
        if isinstance(self.primary_slug, Unset):
            primary_slug = UNSET
        else:
            primary_slug = self.primary_slug


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if profile_id is not UNSET:
            field_dict["profile_id"] = profile_id
        if primary_slug is not UNSET:
            field_dict["primary_slug"] = primary_slug

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_profile_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        profile_id = _parse_profile_id(d.pop("profile_id", UNSET))


        def _parse_primary_slug(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        primary_slug = _parse_primary_slug(d.pop("primary_slug", UNSET))


        combined_search_body_profile_params_exact_profile_type_0_none_of_type_0_item = cls(
            profile_id=profile_id,
            primary_slug=primary_slug,
        )


        combined_search_body_profile_params_exact_profile_type_0_none_of_type_0_item.additional_properties = d
        return combined_search_body_profile_params_exact_profile_type_0_none_of_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="CombinedSearchBodyProfileParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0")



@_attrs_define
class CombinedSearchBodyProfileParamsEducationType0AllOfType0ItemSchoolNameKeywordsType0:
    """ 
        Attributes:
            any_of (Union[None, Unset, list[str]]):
            none_of (Union[None, Unset, list[str]]):
     """

    any_of: Union[None, Unset, list[str]] = UNSET
    none_of: Union[None, Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        any_of: Union[None, Unset, list[str]]
        if isinstance(self.any_of, Unset):
            any_of = UNSET
        elif isinstance(self.any_of, list):
            any_of = self.any_of


        else:
            any_of = self.any_of

        none_of: Union[None, Unset, list[str]]
        if isinstance(self.none_of, Unset):
            none_of = UNSET
        elif isinstance(self.none_of, list):
            none_of = self.none_of


        else:
            none_of = self.none_of


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if any_of is not UNSET:
            field_dict["anyOf"] = any_of
        if none_of is not UNSET:
            field_dict["noneOf"] = none_of

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_any_of(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                any_of_type_0 = cast(list[str], data)

                return any_of_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        any_of = _parse_any_of(d.pop("anyOf", UNSET))


        def _parse_none_of(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                none_of_type_0 = cast(list[str], data)

                return none_of_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        none_of = _parse_none_of(d.pop("noneOf", UNSET))


        combined_search_body_profile_params_education_type_0_all_of_type_0_item_school_name_keywords_type_0 = cls(
            any_of=any_of,
            none_of=none_of,
        )


        combined_search_body_profile_params_education_type_0_all_of_type_0_item_school_name_keywords_type_0.additional_properties = d
        return combined_search_body_profile_params_education_type_0_all_of_type_0_item_school_name_keywords_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.investment_search_response_200_output_investments_item_round_location_country_code_type_1 import InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType1
from ..models.investment_search_response_200_output_investments_item_round_location_country_code_type_2_type_1 import InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType2Type1
from ..models.investment_search_response_200_output_investments_item_round_location_country_code_type_3_type_1 import InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType3Type1
from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="InvestmentSearchResponse200OutputInvestmentsItemRoundLocation")



@_attrs_define
class InvestmentSearchResponse200OutputInvestmentsItemRoundLocation:
    """ Location where the funding round occurred

        Attributes:
            country_code (Union[InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType1,
                InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType2Type1,
                InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType3Type1, None, Unset]): Country code
                where the funding round occurred
            state (Union[None, Unset, str]): State where the funding round occurred
            city (Union[None, Unset, str]): City where the funding round occurred
     """

    country_code: Union[InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType1, InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType2Type1, InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType3Type1, None, Unset] = UNSET
    state: Union[None, Unset, str] = UNSET
    city: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        country_code: Union[None, Unset, str]
        if isinstance(self.country_code, Unset):
            country_code = UNSET
        elif isinstance(self.country_code, InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType1):
            country_code = self.country_code.value
        elif isinstance(self.country_code, InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType2Type1):
            country_code = self.country_code.value
        elif isinstance(self.country_code, InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType3Type1):
            country_code = self.country_code.value
        else:
            country_code = self.country_code

        state: Union[None, Unset, str]
        if isinstance(self.state, Unset):
            state = UNSET
        else:
            state = self.state

        city: Union[None, Unset, str]
        if isinstance(self.city, Unset):
            city = UNSET
        else:
            city = self.city


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if country_code is not UNSET:
            field_dict["countryCode"] = country_code
        if state is not UNSET:
            field_dict["state"] = state
        if city is not UNSET:
            field_dict["city"] = city

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_country_code(data: object) -> Union[InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType1, InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType2Type1, InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType3Type1, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                country_code_type_1 = InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType1(data)



                return country_code_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                country_code_type_2_type_1 = InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType2Type1(data)



                return country_code_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                country_code_type_3_type_1 = InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType3Type1(data)



                return country_code_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType1, InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType2Type1, InvestmentSearchResponse200OutputInvestmentsItemRoundLocationCountryCodeType3Type1, None, Unset], data)

        country_code = _parse_country_code(d.pop("countryCode", UNSET))


        def _parse_state(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        state = _parse_state(d.pop("state", UNSET))


        def _parse_city(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        city = _parse_city(d.pop("city", UNSET))


        investment_search_response_200_output_investments_item_round_location = cls(
            country_code=country_code,
            state=state,
            city=city,
        )


        investment_search_response_200_output_investments_item_round_location.additional_properties = d
        return investment_search_response_200_output_investments_item_round_location

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.text_to_combined_search_response_200_output_profile_search_params_type_0_education_type_0_any_of_type_0_item_finished_school_at_type_1_window_type_2_method import TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Method
from ..models.text_to_combined_search_response_200_output_profile_search_params_type_0_education_type_0_any_of_type_0_item_finished_school_at_type_1_window_type_2_period import TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Period
from ..models.text_to_combined_search_response_200_output_profile_search_params_type_0_education_type_0_any_of_type_0_item_finished_school_at_type_1_window_type_2_which import TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Which






T = TypeVar("T", bound="TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2")



@_attrs_define
class TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2:
    """ 
        Attributes:
            method (TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolA
                tType1WindowType2Method):
            which (TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAt
                Type1WindowType2Which):
            period (TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolA
                tType1WindowType2Period):
     """

    method: TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Method
    which: TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Which
    period: TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Period
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        method = self.method.value

        which = self.which.value

        period = self.period.value


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "method": method,
            "which": which,
            "period": period,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        method = TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Method(d.pop("method"))




        which = TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Which(d.pop("which"))




        period = TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemFinishedSchoolAtType1WindowType2Period(d.pop("period"))




        text_to_combined_search_response_200_output_profile_search_params_type_0_education_type_0_any_of_type_0_item_finished_school_at_type_1_window_type_2 = cls(
            method=method,
            which=which,
            period=period,
        )


        text_to_combined_search_response_200_output_profile_search_params_type_0_education_type_0_any_of_type_0_item_finished_school_at_type_1_window_type_2.additional_properties = d
        return text_to_combined_search_response_200_output_profile_search_params_type_0_education_type_0_any_of_type_0_item_finished_school_at_type_1_window_type_2

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.sync_combined_search_body_profile_params_job_title_v2_type_0_any_of_type_0_item_type_1_groups_item import SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1GroupsItem
from ..models.sync_combined_search_body_profile_params_job_title_v2_type_0_any_of_type_0_item_type_1_type import SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1Type
from typing import cast






T = TypeVar("T", bound="SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1")



@_attrs_define
class SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1:
    """ 
        Attributes:
            type_ (SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1Type):
            groups (list[SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1GroupsItem]):
     """

    type_: SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1Type
    groups: list[SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1GroupsItem]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_.value

        groups = []
        for groups_item_data in self.groups:
            groups_item = groups_item_data.value
            groups.append(groups_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "groups": groups,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1Type(d.pop("type"))




        groups = []
        _groups = d.pop("groups")
        for groups_item_data in (_groups):
            groups_item = SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1GroupsItem(groups_item_data)



            groups.append(groups_item)


        sync_combined_search_body_profile_params_job_title_v2_type_0_any_of_type_0_item_type_1 = cls(
            type_=type_,
            groups=groups,
        )


        sync_combined_search_body_profile_params_job_title_v2_type_0_any_of_type_0_item_type_1.additional_properties = d
        return sync_combined_search_body_profile_params_job_title_v2_type_0_any_of_type_0_item_type_1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class TextToProfileSearchResponse200OutputSearchParamsJobStatusType0Status(str, Enum):
    CURRENTLY_EMPLOYED = "currently-employed"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.kitchen_sink_bulk_profile_response_200_output_data_item_item_publications_type_0_item_collaborators_type_0_item import KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0ItemCollaboratorsType0Item





T = TypeVar("T", bound="KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0Item")



@_attrs_define
class KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0Item:
    """ 
        Attributes:
            collaborators (Union[None, Unset,
                list['KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0ItemCollaboratorsType0Item']]):
            date (Union[None, Unset, str]):
            id (Union[None, Unset, str]):
            publisher (Union[None, Unset, str]):
            summary (Union[None, Unset, str]):
            title (Union[None, Unset, str]):
            url (Union[None, Unset, str]):
     """

    collaborators: Union[None, Unset, list['KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0ItemCollaboratorsType0Item']] = UNSET
    date: Union[None, Unset, str] = UNSET
    id: Union[None, Unset, str] = UNSET
    publisher: Union[None, Unset, str] = UNSET
    summary: Union[None, Unset, str] = UNSET
    title: Union[None, Unset, str] = UNSET
    url: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.kitchen_sink_bulk_profile_response_200_output_data_item_item_publications_type_0_item_collaborators_type_0_item import KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0ItemCollaboratorsType0Item
        collaborators: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.collaborators, Unset):
            collaborators = UNSET
        elif isinstance(self.collaborators, list):
            collaborators = []
            for collaborators_type_0_item_data in self.collaborators:
                collaborators_type_0_item = collaborators_type_0_item_data.to_dict()
                collaborators.append(collaborators_type_0_item)


        else:
            collaborators = self.collaborators

        date: Union[None, Unset, str]
        if isinstance(self.date, Unset):
            date = UNSET
        else:
            date = self.date

        id: Union[None, Unset, str]
        if isinstance(self.id, Unset):
            id = UNSET
        else:
            id = self.id

        publisher: Union[None, Unset, str]
        if isinstance(self.publisher, Unset):
            publisher = UNSET
        else:
            publisher = self.publisher

        summary: Union[None, Unset, str]
        if isinstance(self.summary, Unset):
            summary = UNSET
        else:
            summary = self.summary

        title: Union[None, Unset, str]
        if isinstance(self.title, Unset):
            title = UNSET
        else:
            title = self.title

        url: Union[None, Unset, str]
        if isinstance(self.url, Unset):
            url = UNSET
        else:
            url = self.url


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if collaborators is not UNSET:
            field_dict["collaborators"] = collaborators
        if date is not UNSET:
            field_dict["date"] = date
        if id is not UNSET:
            field_dict["id"] = id
        if publisher is not UNSET:
            field_dict["publisher"] = publisher
        if summary is not UNSET:
            field_dict["summary"] = summary
        if title is not UNSET:
            field_dict["title"] = title
        if url is not UNSET:
            field_dict["url"] = url

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.kitchen_sink_bulk_profile_response_200_output_data_item_item_publications_type_0_item_collaborators_type_0_item import KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0ItemCollaboratorsType0Item
        d = dict(src_dict)
        def _parse_collaborators(data: object) -> Union[None, Unset, list['KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0ItemCollaboratorsType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                collaborators_type_0 = []
                _collaborators_type_0 = data
                for collaborators_type_0_item_data in (_collaborators_type_0):
                    collaborators_type_0_item = KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0ItemCollaboratorsType0Item.from_dict(collaborators_type_0_item_data)



                    collaborators_type_0.append(collaborators_type_0_item)

                return collaborators_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['KitchenSinkBulkProfileResponse200OutputDataItemItemPublicationsType0ItemCollaboratorsType0Item']], data)

        collaborators = _parse_collaborators(d.pop("collaborators", UNSET))


        def _parse_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        date = _parse_date(d.pop("date", UNSET))


        def _parse_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        id = _parse_id(d.pop("id", UNSET))


        def _parse_publisher(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        publisher = _parse_publisher(d.pop("publisher", UNSET))


        def _parse_summary(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        summary = _parse_summary(d.pop("summary", UNSET))


        def _parse_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        title = _parse_title(d.pop("title", UNSET))


        def _parse_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        url = _parse_url(d.pop("url", UNSET))


        kitchen_sink_bulk_profile_response_200_output_data_item_item_publications_type_0_item = cls(
            collaborators=collaborators,
            date=date,
            id=id,
            publisher=publisher,
            summary=summary,
            title=title,
            url=url,
        )


        kitchen_sink_bulk_profile_response_200_output_data_item_item_publications_type_0_item.additional_properties = d
        return kitchen_sink_bulk_profile_response_200_output_data_item_item_publications_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
